@@ -1,6 +1,6 @@
 import jwt
 
-from .serializers import PaymentSerializer
+from .serializers import PaymentSerializer, CancelOrderSerializer
 
 
 class Talar:
@@ -21,8 +21,12 @@ class Talar:
     def url(self):
         return f'{self.base_url}/project/{self.project_id}/payment/create/'
 
-    def create_payment_data(self, data: dict):
-        talar_serializer = PaymentSerializer(data=data)
+    @property
+    def cancel_order_url(self):
+        return f'{self.base_url}/project/{self.project_id}/payment/cancel/'
+
+    def _handle_payment_data(self, serializer, data: dict):
+        talar_serializer = serializer(data=data)
         talar_serializer.is_valid(raise_exception=True)
 
         encrypted_data = jwt.encode(
@@ -32,3 +36,9 @@ class Talar:
             headers={'kid': self.key_id}
         )
         return encrypted_data.decode("utf-8")
+
+    def create_payment_data(self, data: dict):
+        return self._handle_payment_data(PaymentSerializer, data)
+
+    def cancel_payment_data(self, data: dict):
+        return self._handle_payment_data(CancelOrderSerializer, data)
