@@ -15,6 +15,17 @@ class PaymentSerializer(serializers.Serializer):
     provider_code = serializers.CharField(max_length=256, required=False,
                                           allow_blank=True)
 
+    metadata = serializers.JSONField(required=False)
+
+
+class CancelOrderSerializer(serializers.Serializer):
+    order_id = serializers.CharField(max_length=128)
+    continue_url = serializers.URLField(required=False, allow_blank=True)
+    notify_url = serializers.URLField(required=False, allow_blank=True)
+
+    provider_code = serializers.CharField(max_length=256, required=False,
+                                          allow_blank=True)
+
 
 class NotifySerializerV0(serializers.Serializer):
     id = serializers.IntegerField(read_only=True)
